@@ -22,11 +22,9 @@ def mkdir(path):
     # 判断结果
     if not os.path.exists(path):
         os.makedirs(path)
-        # print(path + ' 创建成功')
         return True
     else:
         pass
-        # print(path + ' 目录已存在')
         return False
 
 
@@ -104,5 +102,3 @@ def main(voc_path, division_ratio):
 
 if __name__ == '__main__':
     print("start")
-    params = get_args()
-    main(params.voc_path, params.division_ratio)
